@@ -310,6 +310,9 @@ def deploy_remote_core():
     run('bsjack server.reload_app:{name},VERBOSE={verbose:d} --hide=status'.format(
         name=project_name, verbose=beanstalk_settings['VERBOSE']))
 
+    print green('Deployed to {host}. URL is http://{host}/{project_name}/'.format(
+        host=host_name, project_name=project_name))  # TODO: URL from remote
+
     print separator(' . ')
 
 
